@@ -8,5 +8,5 @@ import policyengine_canada
 import policyengine_ng
 
 # Provide the worker with the list of queues (str) to listen to.
-w = Worker(['default'], connection=Redis())
-w.work()
\ No newline at end of file
+w = Worker(["default"], connection=Redis())
+w.work()
